pub fn detect_file_format(file_path: &Path) -> FileFormatExpand description
Detect file format based on extension and optionally file content
pub fn detect_file_format(file_path: &Path) -> FileFormatDetect file format based on extension and optionally file content